@@ -504,7 +504,7 @@ class Group(Option):
 
     def _is_satisfied(self, parsed):
         for item in self._names:
-            if item in parsed:
+            if item._is_satisfied(parsed):
                 return True
         return False
 
@@ -735,7 +735,6 @@ class Parser(object):
         list(starmap(self._set_requires, permutations(args, 2)))
         return Group(self, *args)
 
-    @_options_to_names
     def only_one_if_any(self, *args):
         ''' If *any* of ``args`` is specified, then none of the remaining
         ``args`` may be specified.'''
@@ -748,7 +747,6 @@ class Parser(object):
 
 # --- private --- #
 
-    @_options_to_names
     def _require_at_least_one(self, *names):
         ''' At least one of the arguments is required. '''
 
@@ -756,6 +754,8 @@ class Parser(object):
         for v in s:
             self._set_required(v, s - set([v]))
 
+        return Group(self, *names)
+
     @localize
     def _set_unspecified_default(self, name):
         if self._unspecified_default is not None:
@@ -1125,4 +1125,4 @@ class IOParser(Parser):
         return self._add_option(name).cast(opener)
 
 
-__version__ = '0.2.11a'
+__version__ = '0.2.12a'
